# Streamlit Tile Grid 
Library to display tile grid which can be used to showcase key metrics within a dashboard or other application. You can use bootstrap icons on the top of your tiles (https://icons.getbootstrap.com/)

## Installation

``` pip install streamlit-tile-grid ```

## Example

![image](https://user-images.githubusercontent.com/37738513/226084229-fdccf39f-05f5-4051-84e9-0e647811c7ee.png)
